#First required to install following R packages
#install.packages("caret")
#install.packages("ROCR")
#install.packages("randomForest")

library("caret")
library("ROCR")
library("kernlab")
library("randomForest")


#Connect to the Prognostic Model
setwd("C:/Users/HP/Desktop/PrognosticModel")
#setwd("F:/PredictionModel")

#Load the Prognostic Model from the Workspace file: Model_SVM_RF.RData
load(file="Model_SVM_RF.RData")

#Check the Prediction performance with Two Independent Test Datasets: Test_Data1 and Test_Data2. 

##---------Upload the independent Test Dataset-1--------------------------
##--Control=0(normal), Case=1(Cancer)
test_data1<-read.csv("Test_Data1.csv",header=T)
test_data1[-1]=scale(test_data1[-1])
test_data1$Class<-as.factor(ifelse(test_data1$Class==1,"Case","Control"))
validate1<-test_data1

#Run the SVM based prediction model as follows. 
val1 <-validate1[,2:ncol(validate1)]
svm.prob1 <- predict(svm.tune, val1, type="prob")
svm.pred2 <-prediction(svm.prob1[,2], validate1$Class)
svm.perf_auc2 <- performance(svm.pred2,"auc")
svm.AUC1<-round(svm.perf_auc2@y.values[[1]],digits=3)
svm.perf_val1 <- performance(svm.pred2, "tpr", "fpr")
plot(svm.perf_val1, col = "green", lwd = 1.5, print.auc = TRUE,legacy.axes=TRUE)
lines(x = c(0,100), y = c(0,100))
legend_svm=paste0("AUC=", svm.AUC1)
legend(.4, .5,legend=rev(legend_svm),  bty = "n", text.font =1)
#Fig.4(A)in the manuscript, Independent_Test_Data_ID: GSE119552 
(svm.pred1_Class <- predict(svm.tune, val1, type="raw"))

#Run the RF based prediction model as follows. 
rf.prob1<-predict(train.rf,newdata=validate1,type="prob")
rf.pred1 <-prediction(rf.prob1[,2], validate1$Class)
rf.perf_auc2 <- performance(rf.pred1, "auc")
RF.AUC1<-round(rf.perf_auc2@y.values[[1]],digits=3)
rf.perf1 <- performance(rf.pred1, "tpr", "fpr")
plot(rf.perf1, col = "green", lwd = 1.5, print.auc = TRUE,legacy.axes=TRUE)
lines(x = c(0,100), y = c(0,100))
legend_RF1=paste0("AUC=", RF.AUC1)
legend(.4, .5,legend=rev(legend_RF1),  bty = "n", text.font =1)
#Fig.4(A)in the manuscript, Independent_Test_Data_ID: GSE119552 
(rf.pred1_Class<-predict(train.rf,newdata=validate1,type="raw"))


##---------Upload the independent Test Dataset-2--------------------------
##--Control=0(normal), Case=1(Cancer)
test_data2<-read.csv("Test_Data2.csv",header=T)
test_data2[-1]=scale(test_data2[-1])
test_data2$Class<-as.factor(ifelse(test_data2$Class==1,"Case","Control"))
validate2<-test_data2

#Run the SVM based prediction model as follows. 
val2 <-validate2[,2:ncol(validate2)]
svm.prob2 <- predict(svm.tune, val2, type="prob")
svm.pred2 <-prediction(svm.prob2[,2], validate2$Class)
svm.perf_auc2 <- performance(svm.pred2,"auc")
svm.AUC2<-round(svm.perf_auc2@y.values[[1]],digits=3)
svm.perf2 <- performance(svm.pred2, "tpr", "fpr")
plot(svm.perf2, col = "green", lwd = 1.5, print.auc = TRUE,legacy.axes=TRUE)
lines(x = c(0,100), y = c(0,100))
legend_svm2=paste0("AUC=", svm.AUC2)
legend(.4, .5,legend=rev(legend_svm2),  bty = "n", text.font =1)
#Fig.4(B)in the manuscript, Independent_Test_Data_ID: GSE152322 
(svm.pred2_Class <- predict(svm.tune, val2, type="raw"))


#Run the RF based prediction model as follows. 
rf.prob2<-predict(train.rf,newdata=validate2,type="prob")
rf.pred2 <-prediction(rf.prob2[,2], validate2$Class)
rf.perf_auc2 <- performance(rf.pred2, "auc")
RF.AUC2<-round(rf.perf_auc2@y.values[[1]],digits=3)
rf.perf2 <- performance(rf.pred2, "tpr", "fpr")
plot(rf.perf2, col = "green", lwd = 1.5, print.auc = TRUE,legacy.axes=TRUE)
lines(x = c(0,100), y = c(0,100))
legend_RF2=paste0("AUC=", RF.AUC2)
legend(.4, .5,legend=rev(legend_RF2),  bty = "n", text.font =1)
#Fig.4(B)in the manuscript, Independent_Test_Data_ID:GSE152322 
(rf.pred2_Class<-predict(train.rf,newdata=validate2,type="raw"))






